<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage FavBlog
 * @since FavBlog 1.0.0
 */

$options = favblog_get_theme_options();  


if ( ! function_exists( 'favblog_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since FavBlog 1.0.0
	 */
	function favblog_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'favblog_doctype', 'favblog_doctype', 10 );


if ( ! function_exists( 'favblog_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'favblog_before_wp_head', 'favblog_head', 10 );

if ( ! function_exists( 'favblog_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'favblog' ); ?></a>

		<?php
	}
endif;
add_action( 'favblog_page_start_action', 'favblog_page_start', 10 );

if ( ! function_exists( 'favblog_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'favblog_page_end_action', 'favblog_page_end', 10 );

if ( ! function_exists( 'favblog_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_site_branding() {
		$options  = favblog_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];
		?>
		 <div class="menu-overlay"></div>
		 <?php if($options['topbar_section_enable']) : ?>
			<div id="top-navigation" class="relative">
				<div class="wrapper">
				<nav id="secondary-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e('Secondary Menu', 'favblog')?>">
					<?php 
					if(has_nav_menu( 'secondary' ) && $options['secondary_menu_enable']) : ?>
						<button class="menu-toggle" aria-controls="secondary-menu" aria-expanded="false" title="<?php esc_attr_e('Secondary Menu', 'favblog')?>">
							<span class="menu-label"><?php esc_html_e('Top', 'favblog'); ?></span> 
							<?php
							echo favblog_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
							echo favblog_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
							?>
						</button>
						<?php  
							wp_nav_menu(  array(
								'theme_location' => 'secondary',
								'menu_class' => 'menu nav-menu',
								'container'=> 'div',
								'menu_id'	=>'secondary-menu',
								'echo' => true,
								'fallback_cb' => false,
							) );
					endif; 

					if($options['social_menu_enable'] && has_nav_menu( 'social' )):
				
						wp_nav_menu(  array(
							'theme_location' => 'social',
							'container' => 'div',
							'container_class' => 'social-icons',
							'echo' => true,
							'depth' => 1,
							'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
							'fallback_cb' => false,
						) );
						
					endif; ?>
					
					</div><!-- .col-2 -->
				</div><!-- .wrapper -->
			</div><!-- #top-bar -->
			<?php endif; ?>
		 <header id="masthead" class="site-header" role="banner">
			
            <div class="wrapper">
                <div class="site-branding">
					<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo( )  ) { ?>
						<div class="site-logo">
							<?php the_custom_logo(); ?>
						</div>
					<?php } 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' )  ) ) : ?>
						<div id="site-identity">
							<?php
							if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
								if ( favblog_is_latest_posts() || favblog_is_frontpage() ) : ?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
								<?php else : ?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
								endif;
							} 
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
								$description = get_bloginfo( 'description', 'display' );
								if ( $description || is_customize_preview() ) : ?>
									<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
								endif; 
							}?>
						</div>
					<?php endif; ?>
				</div><!-- .site-branding -->
				<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e('Primary Menu', 'favblog') ?>">
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="<?php esc_attr_e('Primary Menu', 'favblog') ?>">
				<span class="menu-label"><?php esc_html_e('Menu', 'favblog');?></span>
				<?php
				echo favblog_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
				echo favblog_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
				?>			
				</button>
				<?php  
					$search_html= null;
					if($options['search_icon_in_primary_menu_enable']){
						$search_html = sprintf(
										'<li class="search-menu"><a href="#" title="%1$s">%2$s%3$s</a><div id="search">%4$s</div>',
										esc_attr__('Search','favblog'),
										favblog_get_svg( array( 'icon' => 'search' ) ), 
										favblog_get_svg( array( 'icon' => 'close' ) ), 
										get_search_form( $echo = false )
									);
						
					}else{
						$search_html = '';
					}
					wp_nav_menu( array(
						'theme_location' => 'primary',
						'container' => 'div',
						'menu_class' => 'menu nav-menu',
						'menu_id' => 'primary-menu',
						'echo' => true,
						'fallback_cb' => 'favblog_menu_fallback_cb',
						'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s'.$search_html.'</ul>',
					) );
				?>
				</nav><!-- #site-navigation -->
				<span class="double-border-line"></span>
            </div><!-- .wrapper -->
		</header><!-- .header-->
		<?php
	}
endif;
add_action( 'favblog_header_action', 'favblog_site_branding', 10 );

if ( ! function_exists( 'favblog_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'favblog_content_start_action', 'favblog_content_start', 10 );

if ( ! function_exists( 'favblog_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since FavBlog 1.0.0
     *
     */
    function favblog_header_image() {
        if ( favblog_is_frontpage() )
            return;
        $header_image = get_header_image();
        if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;
        ?>

        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php favblog_custom_header_banner_title(); ?>
                </header>
                <?php favblog_add_breadcrumb(); ?>
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'favblog_header_image_action', 'favblog_header_image', 10 );

if ( ! function_exists( 'favblog_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since FavBlog 1.0.0
	 */
	function favblog_add_breadcrumb() {
		$options = favblog_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( favblog_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * favblog_simple_breadcrumb hook
				 *
				 * @hooked favblog_simple_breadcrumb -  10
				 *
				 */
				do_action( 'favblog_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'favblog_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'favblog_content_end_action', 'favblog_content_end', 10 );

if ( ! function_exists( 'favblog_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'favblog_footer', 'favblog_footer_start', 10 );

if ( ! function_exists( 'favblog_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_footer_site_info() {
		$options = favblog_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'];
		$theme_data = wp_get_theme();
		?>
		<span class="double-border-line"></span>
		<div class="site-info">
                <div class="wrapper">
                    <span>
                    <?php 
	                	echo favblog_santize_allow_tag( $copyright_text ); 
	                	echo " | ".esc_html__( 'Favblog by ', 'favblog' )." <a href='". esc_url( $theme_data->get( 'AuthorURI' ) ) ."'>". esc_html( ucwords( $theme_data->get( 'Author' ) ) ) ."</a>";
	                	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                	?>
                	</span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'favblog_footer', 'favblog_footer_site_info', 40 );

if ( ! function_exists( 'favblog_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_footer_scroll_to_top() {
		$options  = favblog_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo favblog_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'favblog_footer', 'favblog_footer_scroll_to_top', 40 );

if ( ! function_exists( 'favblog_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog 1.0.0
	 *
	 */
	function favblog_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'favblog_footer', 'favblog_footer_end', 100 );